@@ -28,7 +28,7 @@ def check_arcget_output(output):
             return False, need_arcclean
     return True, need_arcclean
 
-class JobActionStats(object):
+class JobActionStats:
 
     def __init__(self):
         self.error_count = 0
