@@ -12,7 +12,7 @@ from arcnagios.nagutils import OK, WARNING, CRITICAL, status_by_name, \
         ServiceUnknown
 from arcnagios.utils import counted_noun
 
-class Glue_Validator(object):
+class Glue_Validator:
 
     def __init__(self, subject, shortname, log):
         self.subject = subject
