@@ -31,7 +31,7 @@ def status_by_name(name):
     except KeyError:
         raise ValueError('%s is not a Nagios status name.' % name)
 
-class NagiosPerfdata(object):
+class NagiosPerfdata:
     def __init__(self, label, value, uom = None,
                  limit_warn = None, limit_crit = None,
                  limit_min = None,  limit_max = None):
@@ -66,7 +66,7 @@ class NagiosPerfdata(object):
         if other.limit_max:  self.limit_max  += other.limit_max
         return self
 
-class NagiosPerflog(object):
+class NagiosPerflog:
     def __init__(self, granular = False):
         self._granular = granular
         self._perfdatas = {}
@@ -89,7 +89,7 @@ class NagiosPerflog(object):
     def __str__(self):
         return ' '.join(map(str, self._perfdatas.values()))
 
-class NagiosReport(object):
+class NagiosReport:
     """Instances of this class collects information to be reported to Nagios.
     You should use one instance for the active check result, and one instance
     for each passive (``host_name``, ``service_description``) kombination to
@@ -109,7 +109,7 @@ class NagiosReport(object):
         """Update the Nagios exit code to the maximum of ``status_code`` and
         the current code."""
 
-        assert OK <= status_code and status_code <= UNKNOWN
+        assert OK <= status_code <= UNKNOWN
         self.status_code_counts[status_code] += 1
         if status_code > self.status_code:
             self.status_code = status_code
@@ -149,7 +149,7 @@ class NagiosReport(object):
 
         return self._log_buffer.getvalue()
 
-class NagiosPlugin(object):
+class NagiosPlugin:
 
     probe_name = None
     bugtracker_url = 'http://bugzilla.nordugrid.org/'
@@ -201,6 +201,11 @@ class NagiosPlugin(object):
                 help = 'Replacement for newlines when submitting multiline '
                        'results to passive services.  Pass the empty string '
                        'drop extra lines.')
+        ap.add_argument('--clip-passive-status',
+                default = None,
+                help = 'The maximum number of characters to publish to a '
+                       'passive service status, including the ellipses which '
+                       'will be added to indicate the that it is clipped.')
         if use_host:
             ap.add_argument('-H', '--host', dest = 'host',
                     help = 'Host of service to check.')
@@ -443,6 +448,10 @@ class NagiosPlugin(object):
             # but it's better than leaving the operator clueless.
             sep = self.opts.multiline_separator
             plugin_output += sep + details.strip().replace('\n', sep)
+        if self.opts.clip_passive_status \
+                and len(plugin_output) > self.opts.clip_passive_status:
+            plugin_output = plugin_output[:self.opts.clip_passive_status-4] \
+                    .rsplit(None, 1)[0] + ' ...'
         rstr = '[%d] PROCESS_SERVICE_CHECK_RESULT;%s;%s;%d;%s\n' % \
                 (t, host_name, svc_description, return_code, plugin_output)
         if self.opts.how_invoked == 'manual':
