@@ -13,7 +13,7 @@ _module_log = logging.getLogger(__name__)
 
 # File Locking
 #
-class locked_open(object):
+class locked_open:
 
     def __init__(self, path, mode='r'):
         assert mode in ['r', 'w']
@@ -34,7 +34,7 @@ class locked_open(object):
 
 # Type Descriptors of the form (decode, encode, required).
 #
-class PersistentType(object):
+class PersistentType:
     def __init__(self, decode, encode = str, required = True):
         self.decode = decode
         self.encode = encode
@@ -65,7 +65,7 @@ pt_json_opt = PersistentType(json.loads, json.dumps, False)
 
 # Persistent Objects
 #
-class PersistentObject(object):
+class PersistentObject:
     """A class which represents a simple collection of attributes with
     human-readable pickeling.  The pickeling is limited to what is needed by
     the Nagios plugins.  The main point of this is to make the data
@@ -108,11 +108,10 @@ class PersistentObject(object):
                     if getattr(self, k) is None:
                         if persistence_version_of_file == persistence_version:
                             raise ParseError('Missing required attribute %s.'%k)
-                        else:
-                            raise ObsoletePersistentObject(
-                                    'Missing required attribute %s in '
-                                    'outdated %s with version %d.'
-                                    % (k, path, persistence_version_of_file))
+                        raise ObsoletePersistentObject(
+                                'Missing required attribute %s in '
+                                'outdated %s with version %d.'
+                                % (k, path, persistence_version_of_file))
 
     def persistent_save(self, path, log=_module_log, persistence_version=0):
         # pylint: disable=unused-argument
