@@ -15,6 +15,17 @@ class ProxyInitError(EnvironmentError):
         EnvironmentError.__init__(self, msg)
         self.details = details
 
+try:
+    from cryptography import x509
+    from cryptography.hazmat.backends import default_backend
+    def _x509_certificate_not_valid_after(cert_path):
+        with open(cert_path, mode='rb') as fh:
+            data = fh.read()
+            backend = default_backend()
+            return x509.load_pem_x509_certificate(data, backend).not_valid_after
+except ImportError:
+    _x509_certificate_not_valid_after = None
+
 def _require_voms_proxy(voms, key_path, cert_path, proxy_path,
                         min_proxy_lifetime, max_proxy_age):
 
@@ -25,19 +36,15 @@ def _require_voms_proxy(voms, key_path, cert_path, proxy_path,
     else:
         must_renew = False
         if not min_proxy_lifetime is None:
-            try:
-                from cryptography import x509
-                from cryptography.hazmat.backends import default_backend
-                with open(proxy_path, mode='rb') as fh:
-                    data = fh.read()
-                    backend = default_backend()
-                    cert = x509.load_pem_x509_certificate(data, backend)
-                    t_rem = cert.not_valid_after - datetime.now()
-                    if t_rem.total_seconds() >= min_proxy_lifetime:
-                        log.debug('Proxy valid until %s.', cert.not_valid_after)
-                    else:
-                        must_renew = True
-            except ImportError:
+            if _x509_certificate_not_valid_after is not None:
+                t_xpr = _x509_certificate_not_valid_after(proxy_path)
+                t_rem = t_xpr - datetime.now()
+                if t_rem.total_seconds() >= min_proxy_lifetime:
+                    log.debug('The proxy certificate is valid until %s.', t_xpr)
+                else:
+                    log.debug('The proxy certificate expired %s.', t_xpr)
+                    must_renew = True
+            else:
                 log.info('No cryptography support, using file age.')
                 max_proxy_age = max_proxy_age or (4 * 3600)
         if not max_proxy_age is None:
@@ -76,7 +83,7 @@ def _require_voms_proxy(voms, key_path, cert_path, proxy_path,
                         % p.returncode,
                     details = 'Output from %s:\n%s' % (cmd, output))
 
-class NagiosPluginVomsMixin(object):
+class NagiosPluginVomsMixin:
     def __init__(self):
         ap = self.argparser.add_argument_group('VOMS Proxy Options')
         ap.add_argument('--user-proxy', dest = 'user_proxy',
